#
# spec file for package torbrowser-launcher
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           torbrowser-launcher
Version:        0.2.9
Release:        7.1
Summary:        Tool for launching and easy-updates of Tor Browser
License:        MIT
Group:          Productivity/Networking/Web/Utilities
Url:            https://github.com/micahflee/torbrowser-launcher
Source:         https://github.com/micahflee/%{name}/archive/v%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE pythontorbrowser-launcher-fix-distro-name.patch badshah400@gmail.com -- Use the correct distribution name (the setup.py code gives "SuSE" instead of "openSUSE")
Patch0:         torbrowser-launcher-fix-distro-name.patch
BuildRequires:  apparmor-abstractions
BuildRequires:  python-devel
BuildRequires:  python-gtk
BuildRequires:  python-psutil
BuildRequires:  python-twisted
BuildRequires:  update-desktop-files
BuildRequires:  wmctrl
Requires:       python-Parsley
%if 0%{?suse_version} < 1500
Requires:       python-gpgme
%else
Requires:       python-gpg
%endif
Requires:       python-gtk
Requires:       python-psutil
Requires:       python-pygame
Requires:       python-pyliblzma
Requires:       python-service_identity
Requires:       python-twisted
Requires:       python-txsocksx
Requires:       wmctrl
Recommends:     %{name}-lang = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Tor Browser Launcher is intended to make Tor Browser easier to
install and use for GNU/Linux users. You install
torbrowser-launcher from your distribution's package manager and
it handles everything else:
  - Downloads and installs the most recent version of Tor Browser
    in your language and for your computer's architecture, or
    launches Tor Browser if it's already installed (Tor Browser
    will automatically update itself)
  - Certificate pins to https://www.torproject.org, so it doesn't
    rely on certificate authorities
  - Verifies Tor Browser's signature for you, to ensure the
    version you downloaded was cryptographically signed by Tor
    developers and was not tampered with
  - Adds "Tor Browser" and "Tor Browser Launcher Settings"
    application launcher to your desktop environment's menu
  - Apparmor profile to limit effect of Tor network compromise
  - Optionally plays a modem sound when you open Tor Browser
    (because Tor is so slow).

%package -n torbrowser-apparmor-profile
Summary:        Apparmor profile for Tor Browser
License:        BSD-3-Clause
Group:          Productivity/Security
Requires:       apparmor-utils

%description -n torbrowser-apparmor-profile
This package provides the apparmor profiles to safeguard against
a Tor network compromise.

%lang_package
%prep
%setup -q
%patch0 -p1

%build
python setup.py build

%install
python setup.py install --skip-build --root %{buildroot}
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/torbrowser.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/torbrowser-settings.desktop
%find_lang %{name} %{?no_lang_C}

# REMOVE USELESS TOPLEVEL .mo FILE
rm -fr %{buildroot}%{_datadir}/locale/%{name}.mo

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%doc LICENSE CHANGELOG.md README.md
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%if 0%{?suse_version} <= 1315
%dir %{_datadir}/metainfo
%endif
%{_datadir}/metainfo/torbrowser.appdata.xml
%{_datadir}/pixmaps/torbrowser*.png
%{_datadir}/%{name}/
%{python_sitelib}/torbrowser_launcher-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/torbrowser_launcher/

%files -n torbrowser-apparmor-profile
%defattr(-,root,root)
%doc apparmor/license.txt
%config %{_sysconfdir}/apparmor.d/torbrowser.*
%config %{_sysconfdir}/apparmor.d/local/torbrowser.*
%config %{_sysconfdir}/apparmor.d/tunables/torbrowser

%files lang -f %{name}.lang

%changelog
* Tue Feb  6 2018 badshah400@gmail.com
- Require python-gpgpme for openSUSE < 1500 instead of python-gpg.
* Mon Feb  5 2018 badshah400@gmail.com
- Update to version 0.2.9 [boo#1023279]:
  * Fixed crash issue related to Tor Browser 7.5 changing how the
    currently installed version number is stored
  * Updated list of Tor Project dist mirrors
  * Fixed edge case crash for when stdout isn't writable
  * Updated AppStream metadata
  * Updated AppArmor profiles
- Only run post[un] scripts for openSUSE < 1500; these macros are
  void for newer versions, where rpm triggers automatically take
  care of the appropriate action.
* Sun Jul  2 2017 badshah400@gmail.com
- Update to version 0.2.8:
  * Update URL to check for latest version, which changed in Tor
    Browser 7.
  * Automatically refresh GPG keyring, to prevent signature
    verification false positives.
  * Improve GnuPG code by using GPGME if available.
  * Updated AppArmor profiles.
  * Added Czech, Hungarian localization.
* Mon Feb 13 2017 badshah400@gmail.com
- Update to version 0.2.7:
  * Updated Tor Browser signing key because they added a new
    subkey and verification was failing.
  * Updated AppArmor profiles.
  * Improved localization, and added Russian.
- Split out a %%{name}-lang package with all the non_C language
  translations; remove useless top-level
  %%{_datadir}/locale/%%{name}.mo file.
* Tue Feb  7 2017 badshah400@gmail.com
- Add Requires: python-Parsley to fix downloading through tor
  local server (boo#1023484).
* Sun Aug  7 2016 badshah400@gmail.com
- Update to version 0.2.6:
  + Fixed bug related to fallback to English feature that caused
    Settings to crash.
* Wed Jul 20 2016 badshah400@gmail.com
- Update to version 0.2.5:
  + Fix issue where Tor Browser Launcher failed to launch if
    currently installed version of Tor Browser was too old.
  + If Tor Browser download isn't available in your language,
    fallback to English.
  + Avoid re-downloading tarball if it's already present.
  + Verify GnuPG importing keys using status-fd rather than exit
    codes.
  + Various AppArmor improvements.
  + Remove unused dependency of IPolicyForHTTPS.
* Thu Mar 17 2016 badshah400@gmail.com
- Update to version 0.2.4:
  + Fix signature verification bypass attack.
- Changes from version 0.2.3:
  + Removed certificate pinning to https://www.torproject.org to
    avoid issues with upcoming certificate change, and hard-coded
    minimum Tor Browser version in the release.
  + Fix issue with detecting language.
  + Make Tor SOCKS5 proxy configurable, for users not running on
    9050.
  + Improved AppArmor profiles.
  + Added translations.
  + Switched from xpm icons to png icons.
  + Changed "Exit" button to "Cancel" button.
  + New package description.
* Fri Nov 27 2015 badshah400@gmail.com
- Initial package (rename of python-torbrowser-launcher).
- Patch torbrowser-launcher-fix-distro-name.patch added, fixes
  distro name used by application.
